@@ -5,7 +5,7 @@ import boto3
 import click
 import uuid
 from bentoml.exceptions import BentoMLException
-from bentoml.utils.lazy_loader import LazyLoader
+#from bentoml.utils.lazy_loader import LazyLoader
 from botocore.client import Config
 from kubernetes import client
 
@@ -14,7 +14,7 @@ from bentoutils.print_kaniko_manifest import camel_to_kebab, gen_manifest as gen
 from bentoutils.print_knative_manifest import gen_manifest as gen_knative_manifest
 from bentoutils.print_route_manifest import gen_manifest as gen_route_manifest
 
-yatai_proto = LazyLoader('yatai_proto', globals(), 'bentoml.yatai.proto')
+#yatai_proto = LazyLoader('yatai_proto', globals(), 'bentoml.yatai.proto')
 
 
 @click.command()
@@ -220,7 +220,8 @@ def get_kaniko_manifest(bento, path, registry, s3_endpoint, insecure=False, isdo
 @click.option('--svcname', help='service name')
 @click.option('--tolerations', help='tolerations')
 @click.option('--auth', is_flag=True, help='secure endpoints using oauth2')
-def get_knative_manifest(bento, registry, selector=None, svcname=None, tolerations=None, auth=False):
+@click.option('--labels', help='comma separated list of key:val pairs')
+def get_knative_manifest(bento, registry, selector=None, svcname=None, tolerations=None, auth=False, labels=None):
     if ':' in bento:
         name, version = bento.split(':')
     else:
@@ -231,7 +232,10 @@ def get_knative_manifest(bento, registry, selector=None, svcname=None, toleratio
     if selector is not None:
         selector = convert_labels(selector)
 
-    manifest = gen_knative_manifest(pod_name, version, registry, selector, svcname, tolerations, auth)
+    if labels is not None:
+        labels = convert_labels(labels)
+
+    manifest = gen_knative_manifest(pod_name, version, registry, selector, svcname, tolerations, auth, labels)
     click.echo(manifest)
     return manifest
 
@@ -261,7 +265,7 @@ def get_saved_path(bento, silent=False):
     yatai_client = get_default_yatai_client()
     result = None
     try:
-        result = yatai_client.repository.get(bento)
+        result = yatai_client.pull_bento(bento)
     except BentoMLException as e:
         click.echo(str(e))
         sys.exit(1)
@@ -269,7 +273,7 @@ def get_saved_path(bento, silent=False):
     if result is None:
         return None
 
-    saved_path = result.uri.uri
+    saved_path = result.path
     if not silent: click.echo(saved_path)
     return saved_path
 
@@ -327,9 +331,10 @@ def delete_containerize_job(ctx, bento, pod, registry, isdockerconfig=False):
 @click.option('--svcname', help='service name')
 @click.option('--tolerations', help='tolerations as comma separated list of key=val pairs')
 @click.option('--auth', is_flag=True, help='secure endpoints using oauth2')
+@click.option('--labels', help='comma separated list of key:val pairs')
 @click.pass_context
-def deploy_to_knative(ctx, bento, registry, selector=None, svcname=None, tolerations=None, auth=False):
-    manifest = ctx.invoke(get_knative_manifest, bento=bento, registry=registry, selector=selector, svcname=svcname, tolerations=tolerations, auth=auth)
+def deploy_to_knative(ctx, bento, registry, selector=None, svcname=None, tolerations=None, auth=False, labels=None):
+    manifest = ctx.invoke(get_knative_manifest, bento=bento, registry=registry, selector=selector, svcname=svcname, tolerations=tolerations, auth=auth, labels=labels)
     from_yaml(manifest)
 
     # Build Docker image
@@ -358,16 +363,16 @@ def deploy_to_knative(ctx, bento, registry, selector=None, svcname=None, tolerat
 
 
 def get_default_yatai_client():
-    from bentoml.yatai.client import YataiClient
+    from bentoml import YataiClient
 
     return YataiClient()
 
 
 # This function assumes the status is not status.OK
-def status_pb_to_error_code_and_message(pb_status) -> (int, str):
-    from bentoml.yatai.proto import status_pb2
+#def status_pb_to_error_code_and_message(pb_status) -> (int, str):
+#    from bentoml.yatai.proto import status_pb2
 
-    assert pb_status.status_code != status_pb2.Status.OK
-    error_code = status_pb2.Status.Code.Name(pb_status.status_code)
-    error_message = pb_status.error_message
-    return error_code, error_message
+#    assert pb_status.status_code != status_pb2.Status.OK
+#    error_code = status_pb2.Status.Code.Name(pb_status.status_code)
+#    error_message = pb_status.error_message
+#    return error_code, error_message
